pub struct NormalRandomInitializer {
    pub mean: f32,
    pub standard_deviation: f32,
}
A Initializer that generates random numbers in a normal distribution based on a mean and a standard deviation provided by the new method

Fields

mean: f32

The mean for the Normal distribution

standard_deviation: f32

The standard deviation for the Normal distribution

Implementations

Creates a new Normal Random initializer