pub enum ModelGradientApplicationError {
    NotInitialized,
    NoCommandQueue,
    NoDevice,
    NoLayers,
    OpenCL(ClError),
    ModelPrediction(ModelPredictionError),
    LayerGradientApllication(usizeLayerGradientApplicationError),
}
An enum containing all of the errors that can happen while applying particular gradients to a Model.

Variants



NotInitialized

Happens when the Model was not initialized.



NoCommandQueue

Happens when there is no command queue in the current opencl state.



NoDevice

Happens when there is no device in the current opencl state.



NoLayers

Happens when the Model has no layers inside of it



OpenCL(ClError)

Happens when there goes something wrong with OpenCL.



ModelPrediction(ModelPredictionError)

Happens when the propagation of a layer goes wrong.



LayerGradientApllication(usizeLayerGradientApplicationError)

Happens when the gradient application of a layer goes wrong.

This error contains the index of the layer on which th error happenned and the actual error.