Enum intricate::utils::opencl::BufferOperationError
source · pub enum BufferOperationError {
OpenCLError(ClError),
ProgramNotFoundError(ProgramNotFoundError),
KernelNotFoundError(KernelNotFoundError),
BuffersAreNotOfSameSize(usize, usize),
NoDeviceFoundError,
NoCommandQueueFoundError,
}Expand description
All of the possible errors that may happen while trying to run any buffer operation on a certain buffer
Variants
OpenCLError(ClError)
Just a plain old OpenCL C error
ProgramNotFoundError(ProgramNotFoundError)
This means that the program for the buffer operations has not yet been compiled because it could not be found
KernelNotFoundError(KernelNotFoundError)
This means that the Kernel (OpenCL’s shader) for the operation in question was not found, that may mean there is a problem in Intricate’s code, so you should report this as an issue.
BuffersAreNotOfSameSize(usize, usize)
An error that happens when doing an operation that requires two buffers and that requires that both buffers are of the same size and count.
NoDeviceFoundError
This just means that the operation did ot find any device for it to run on.
NoCommandQueueFoundError
This means that there is no command queue associated with the device, this may be a problem in Intricate’s source code, so please report this in an issue.